(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 10.2' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[    134893,       3301]
NotebookOptionsPosition[    127705,       3072]
NotebookOutlinePosition[    128128,       3088]
CellTagsIndexPosition[    128085,       3085]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[{
 StyleBox["Methoden der Bioinformatik",
  FontSize->24,
  FontWeight->"Bold"],
 StyleBox[" \n\n",
  FontSize->12],
 "Eine Einf\[UDoubleDot]hrung zur Anwendung in Biologie und Medizin\n\n2. \
Auflage",
 StyleBox["\n",
  FontSize->18,
  FontWeight->"Bold"],
 StyleBox["\n",
  FontSize->12],
 "Marc-Thorsten H\[UDoubleDot]tt",
 StyleBox[" ",
  FontSize->12,
  FontWeight->"Bold"],
 "und",
 StyleBox[" ",
  FontSize->12,
  FontWeight->"Bold"],
 "Manuel Dehnert\n",
 StyleBox["\n",
  FontSize->12],
 "Springer Spektrum",
 StyleBox[" ",
  FontSize->12,
  FontWeight->"Bold"],
 "2006",
 StyleBox[", ",
  FontSize->12,
  FontWeight->"Bold"],
 "2016, ISBN 978-3-662-46149-5"
}], "Subsubtitle",
 CellChangeTimes->{{3.669868691792925*^9, 3.669868786167323*^9}, {
  3.6698688284727426`*^9, 3.669868879042635*^9}, {3.6698691142260866`*^9, 
  3.6698691148331213`*^9}}],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "-Exkurs: CpG-Inseln"
}], "Subtitle",
 CellChangeTimes->{3.670321495640956*^9},
 Background->RGBColor[
  0.8705882352941177, 0.00392156862745098, 0.2196078431372549]],

Cell[TextData[{
 "F\[UDoubleDot]r die folgende Untersuchung verwenden wir das menschliche \
Chromosom 19 als Datengrundlage. Der erste Schritt besteht in der \
Unterteilung des Chromosoms in zwei gleich gro\[SZ]e H\[ADoubleDot]lften \
(Segment A und Segment B). Wir werden zuerst zwei unabh\[ADoubleDot]ngige \
Markov-Modelle mit den im Segment A identifizierten CpG-Inseln trainieren \
(Teil 1), um danach die Analysierst\[ADoubleDot]rke dieser Markov-Modelle \
anhand von Segment B zu \[UDoubleDot]berpr\[UDoubleDot]fen (Teil 2). Im \
dritten Teil des ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "-Exkurses wird ein einfaches Hidden-Markov-Modell entworfen, das eine \
symbolgenaue Vorhersage von CpG-Inseln erlauben soll.\n\n",
 StyleBox["Teil 1",
  FontWeight->"Bold"],
 "\nUm ein Markov-Modell festzulegen, ben\[ODoubleDot]tigt man \
Trainingsdatens\[ADoubleDot]tze, deren Eigenschaft in Bezug auf das Modell \
bekannt ist. In dem hier diskutierten Beispiel handelt es sich dabei um \
CpG-Inseln im Segment A des menschlichen Chromosoms 19 und Abschnitte \
desselben Segments, die nicht als CpG-Inseln annotiert sind. Die Annotation \
von CpG Inseln erfolgt dabei mit dem Programm ",
 StyleBox["CpG island searcher",
  FontSlant->"Italic"],
 " und man erh\[ADoubleDot]lt jeweils eine Datei von durch Absatzzeichen \
getrennten CpG-Inseln und entsprechend Sequenzabschnitten, die keine \
CpG-Inseln darstellen. Solche Dateien k\[ODoubleDot]nnen aus den \
identifizierten Grenzen der CpG-Inseln (vgl. Abb. 2.61) und der vollst\
\[ADoubleDot]ndigen Sequenz leicht erzeugt werden. Die als CpG-Inseln \
annotierten Sequenzen werden von dem lokalen Datentr\[ADoubleDot]ger \
eingelesen, wobei wir uns auf die auf die ersten 500 000 Symbole beschr\
\[ADoubleDot]nken."
}], "Text",
 CellChangeTimes->{
  3.674629266696652*^9, {3.674629392986842*^9, 3.67462948344998*^9}, {
   3.674631434822935*^9, 3.674631464824979*^9}, {3.6774933021267653`*^9, 
   3.67749336722768*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"SetDirectory", "[", 
   RowBox[{"NotebookDirectory", "[", "]"}], "]"}], ";"}]], "Input",
 FontColor->GrayLevel[0],
 Background->RGBColor[0.87, 0.94, 1]],

Cell[BoxData[
 RowBox[{
  RowBox[{"CpG", "=", 
   RowBox[{
    RowBox[{"ReadList", "[", 
     RowBox[{
     "\"\<HU19A_CpG_Islands.txt\>\"", ",", "Character", ",", "500000", ",", 
      RowBox[{"RecordLists", "\[Rule]", "True"}], ",", 
      RowBox[{"RecordSeparators", "\[Rule]", " ", 
       RowBox[{"{", 
        RowBox[{"\"\<\\r\\n\>\"", ",", "\"\<\\n\>\"", ",", "\"\<\\r\>\""}], 
        "}"}]}]}], "]"}], "//", "Flatten"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.6774940845201426`*^9, 3.677494116312999*^9}, {
  3.677553674486966*^9, 3.6775536798221755`*^9}}],

Cell["\<\
Das Sch\[ADoubleDot]tzen der \[CapitalUDoubleDot]bergangswahrscheinlichkeiten \
wird durch eine Funktion realisiert, die als Argument die Sequenz hat und als \
R\[UDoubleDot]ckgabewert die 16 m\[ODoubleDot]glichen \
\[CapitalUDoubleDot]bergangswahrscheinlichkeiten in Form einer Liste.\
\>", "Text",
 CellChangeTimes->{{3.674629511587023*^9, 3.674629525842044*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"base", " ", "=", " ", 
    RowBox[{"{", 
     RowBox[{
     "\"\<A\>\"", ",", " ", "\"\<G\>\"", ",", " ", "\"\<C\>\"", ",", " ", 
      "\"\<T\>\""}], "}"}]}], ";"}], " "}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"baseX", " ", "=", " ", 
  RowBox[{"Flatten", "[", 
   RowBox[{
    RowBox[{"Outer", "[", 
     RowBox[{"List", ",", "base", ",", "base"}], "]"}], ",", "1"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.574160445890625*^9, 3.574160512890625*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"\<\"A\"\>", ",", "\<\"A\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"A\"\>", ",", "\<\"G\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"A\"\>", ",", "\<\"C\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"A\"\>", ",", "\<\"T\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"G\"\>", ",", "\<\"A\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"G\"\>", ",", "\<\"G\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"G\"\>", ",", "\<\"C\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"G\"\>", ",", "\<\"T\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"C\"\>", ",", "\<\"A\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"C\"\>", ",", "\<\"G\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"C\"\>", ",", "\<\"C\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"C\"\>", ",", "\<\"T\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"T\"\>", ",", "\<\"A\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"T\"\>", ",", "\<\"G\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"T\"\>", ",", "\<\"C\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"T\"\>", ",", "\<\"T\"\>"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.677571470337911*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"estimateTrans", "[", "seq_", "]"}], ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"par", ",", "length"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"par", " ", "=", " ", 
      RowBox[{"Partition", "[", 
       RowBox[{"seq", ",", "2", ",", "1"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"length", " ", "=", " ", 
      RowBox[{"Length", "[", "par", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"N", "[", 
      RowBox[{
       RowBox[{"Map", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"Count", "[", 
           RowBox[{"par", ",", "#"}], "]"}], "&"}], ",", "baseX"}], "]"}], 
       "/", "length"}], "]"}]}]}], "]"}]}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"matrixCpG", " ", "=", " ", 
  RowBox[{"estimateTrans", "[", "CpG", "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0.03731807463614927`", ",", "0.06685613371226742`", ",", 
   "0.04721809443618887`", ",", "0.0256500513001026`", ",", 
   "0.05869211738423477`", ",", "0.11946223892447785`", ",", 
   "0.09971419942839886`", ",", "0.04856009712019424`", ",", 
   "0.06324612649225299`", ",", "0.07471814943629887`", ",", 
   "0.11477222954445909`", ",", "0.06562013124026247`", ",", 
   "0.017786035572071143`", ",", "0.06539213078426157`", ",", 
   "0.05665411330822662`", ",", "0.03834007668015336`"}], "}"}]], "Output",
 CellChangeTimes->{3.6775714714923134`*^9}]
}, Open  ]],

Cell["\<\
Diese werden im n\[ADoubleDot]chsten Schritt normiert und formatiert \
ausgegeben.\
\>", "Text",
 CellChangeTimes->{{3.674629541332069*^9, 3.6746295516970844`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"normalize", "[", "list_", "]"}], ":=", " ", 
  RowBox[{"N", "[", 
   RowBox[{"list", "/", 
    RowBox[{"Plus", "@@", "list"}]}], "]"}]}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"matrixCpG", " ", "=", 
  RowBox[{"Flatten", "[", " ", 
   RowBox[{"Map", "[", 
    RowBox[{"normalize", ",", 
     RowBox[{"Partition", "[", 
      RowBox[{"matrixCpG", ",", "4"}], "]"}]}], "]"}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0.21078614114165`", ",", "0.3776279075021746`", ",", "0.266705075631771`", 
   ",", "0.14488087572440436`", ",", "0.17980075238643745`", ",", 
   "0.3659673802492433`", ",", "0.305470118984891`", ",", 
   "0.14876174837942824`", ",", "0.1986643882948649`", ",", 
   "0.23469951877772055`", ",", "0.3605146439834651`", ",", 
   "0.20612144894394954`", ",", "0.0998248883101722`", ",", 
   "0.36701614170576746`", ",", "0.3179736434456593`", ",", 
   "0.2151853265384011`"}], "}"}]], "Output",
 CellChangeTimes->{3.6775714715547132`*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"formateM", "[", "mat_", "]"}], ":=", 
  RowBox[{
   RowBox[{"Transpose", "[", 
    RowBox[{"Prepend", "[", 
     RowBox[{
      RowBox[{"Transpose", "[", 
       RowBox[{"Prepend", "[", 
        RowBox[{
         RowBox[{"Partition", "[", 
          RowBox[{"mat", ",", "4"}], "]"}], ",", " ", "base"}], "]"}], "]"}], 
      ",", 
      RowBox[{"Flatten", "[", 
       RowBox[{"{", 
        RowBox[{"\"\< \>\"", ",", " ", "base"}], "}"}], "]"}]}], "]"}], "]"}],
    " ", "//", " ", "TableForm"}]}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"formateM", "[", "matrixCpG", "]"}]], "Input"],

Cell[BoxData[
 TagBox[GridBox[{
    {"\<\" \"\>", "\<\"A\"\>", "\<\"G\"\>", "\<\"C\"\>", "\<\"T\"\>"},
    {"\<\"A\"\>", "0.21078614114165`", "0.3776279075021746`", 
     "0.266705075631771`", "0.14488087572440436`"},
    {"\<\"G\"\>", "0.17980075238643745`", "0.3659673802492433`", 
     "0.305470118984891`", "0.14876174837942824`"},
    {"\<\"C\"\>", "0.1986643882948649`", "0.23469951877772055`", 
     "0.3605146439834651`", "0.20612144894394954`"},
    {"\<\"T\"\>", "0.0998248883101722`", "0.36701614170576746`", 
     "0.3179736434456593`", "0.2151853265384011`"}
   },
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[2.0999999999999996`]}, 
       Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}, "RowsIndexed" -> {}}],
  Function[BoxForm`e$, 
   TableForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.677571471585913*^9}]
}, Open  ]],

Cell["\<\
Damit liegt ein erstes Ergebnis vor, n\[ADoubleDot]mlich die Parameter des \
\[OpenCurlyQuote]+\[CloseCurlyQuote]-Zweigs dieser beiden Markov-Modelle. Um \
nun auch die Parameter des \[OpenCurlyQuote]-\[CloseCurlyQuote]-Zweigs zu sch\
\[ADoubleDot]tzen, lesen wir die in einer anderen Datei abgelegten \
Sequenzsegmente ohne annotierte CpG-Inseln ein. Dabei beschr\[ADoubleDot]nken \
wir uns erneut auf die ersten 500 000 Symbole.\
\>", "Text",
 CellChangeTimes->{{3.6746295710561132`*^9, 3.6746295775911236`*^9}, {
  3.674629611614176*^9, 3.6746296141401806`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"NoCpG", "=", 
   RowBox[{
    RowBox[{"ReadList", "[", 
     RowBox[{
     "\"\<HU19A_NoCpG_Islands.txt\>\"", ",", "Character", ",", "500000", ",", 
      RowBox[{"RecordLists", "\[Rule]", "True"}], ",", 
      RowBox[{"RecordSeparators", "\[Rule]", " ", 
       RowBox[{"{", 
        RowBox[{"\"\<\\r\\n\>\"", ",", "\"\<\\n\>\"", ",", "\"\<\\r\>\""}], 
        "}"}]}]}], "]"}], "//", "Flatten"}]}], ";"}]], "Input"],

Cell["\<\
Diese Daten durchlaufen nun dieselbe Prozedur wie f\[UDoubleDot]r den anderen \
Zweig. Das Resultat ist die normierte und formatierte Matrix der \
\[CapitalUDoubleDot]bergangswahrscheinlichkeiten f\[UDoubleDot]r den '-' - \
Zweig.\
\>", "Text",
 CellChangeTimes->{{3.674629667011258*^9, 3.674629706971322*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"matrixNoCpG", "=", 
  RowBox[{"estimateTrans", "[", "NoCpG", "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0.07982815965631931`", ",", "0.0752241504483009`", ",", 
   "0.056586113172226345`", ",", "0.056234112468224934`", ",", 
   "0.06416212832425665`", ",", "0.08089616179232359`", ",", 
   "0.05762811525623051`", ",", "0.04747009494018988`", ",", 
   "0.0802001604003208`", ",", "0.021524043048086097`", ",", 
   "0.07688415376830754`", ",", "0.06969213938427876`", ",", 
   "0.04368408736817474`", ",", "0.07251014502029005`", ",", 
   "0.05720211440422881`", ",", "0.0602741205482411`"}], "}"}]], "Output",
 CellChangeTimes->{3.677571472599915*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"matrixNoCpG", "=", 
  RowBox[{"Flatten", "[", " ", 
   RowBox[{"Map", "[", 
    RowBox[{"normalize", ",", 
     RowBox[{"Partition", "[", 
      RowBox[{"matrixNoCpG", ",", "4"}], "]"}]}], "]"}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0.29800800382272125`", ",", "0.28082069047903474`", ",", 
   "0.21124268307251223`", ",", "0.20992862262573167`", ",", 
   "0.2564879515182526`", ",", "0.3233822095012712`", ",", 
   "0.2303682502118678`", ",", "0.1897615887686084`", ",", 
   "0.32299637535239634`", ",", "0.08668546113572294`", ",", 
   "0.3096415626258559`", ",", "0.280676600886025`", ",", 
   "0.18694740445928018`", ",", "0.3103094107074079`", ",", 
   "0.24479821971155905`", ",", "0.2579449651217529`"}], "}"}]], "Output",
 CellChangeTimes->{3.6775714726623154`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 StyleBox[
  RowBox[{"formateM", "[", "matrixNoCpG", "]"}],
  FontColor->GrayLevel[0]]], "Input"],

Cell[BoxData[
 TagBox[GridBox[{
    {"\<\" \"\>", "\<\"A\"\>", "\<\"G\"\>", "\<\"C\"\>", "\<\"T\"\>"},
    {"\<\"A\"\>", "0.29800800382272125`", "0.28082069047903474`", 
     "0.21124268307251223`", "0.20992862262573167`"},
    {"\<\"G\"\>", "0.2564879515182526`", "0.3233822095012712`", 
     "0.2303682502118678`", "0.1897615887686084`"},
    {"\<\"C\"\>", "0.32299637535239634`", "0.08668546113572294`", 
     "0.3096415626258559`", "0.280676600886025`"},
    {"\<\"T\"\>", "0.18694740445928018`", "0.3103094107074079`", 
     "0.24479821971155905`", "0.2579449651217529`"}
   },
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[2.0999999999999996`]}, 
       Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}, "RowsIndexed" -> {}}],
  Function[BoxForm`e$, 
   TableForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.6775714726623154`*^9}]
}, Open  ]],

Cell["\<\
Die Trennkraft zwischen den beiden Zweigen, die durch jedes Symbolpaar \
gegeben ist, erfasst man \[Dash] wie wir bereits gesehen haben \[Dash] durch \
die \[Beta]-Werte, die sich einfach als Logarithmus der Quotienten jedes \
Matrixeintrags ergeben:\
\>", "Text",
 CellChangeTimes->{{3.674629730183358*^9, 3.6746297836164484`*^9}, {
  3.677564245605643*^9, 3.677564248008047*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"betaValues", "=", 
   RowBox[{"Log", "[", 
    RowBox[{"2", ",", 
     RowBox[{"matrixCpG", "/", "matrixNoCpG"}]}], "]"}]}], ";"}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"formateM", "[", "betaValues", "]"}]], "Input"],

Cell[BoxData[
 TagBox[GridBox[{
    {"\<\" \"\>", "\<\"A\"\>", "\<\"G\"\>", "\<\"C\"\>", "\<\"T\"\>"},
    {"\<\"A\"\>", 
     RowBox[{"-", "0.4995710635861614`"}], "0.4273161515303086`", 
     "0.33634391005454994`", 
     RowBox[{"-", "0.535031711944819`"}]},
    {"\<\"G\"\>", 
     RowBox[{"-", "0.5124919991440672`"}], "0.17847474978722103`", 
     "0.4070893673361725`", 
     RowBox[{"-", "0.35118438494484655`"}]},
    {"\<\"C\"\>", 
     RowBox[{"-", "0.7011846905744029`"}], "1.4369529334061413`", 
     "0.21945872762196222`", 
     RowBox[{"-", "0.4454141568178625`"}]},
    {"\<\"T\"\>", 
     RowBox[{"-", "0.9051609834413942`"}], "0.24213606558364872`", 
     "0.3773141206402933`", 
     RowBox[{"-", "0.2614835824718115`"}]}
   },
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[2.0999999999999996`]}, 
       Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}, "RowsIndexed" -> {}}],
  Function[BoxForm`e$, 
   TableForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.677571472677915*^9}]
}, Open  ]],

Cell[TextData[{
 "Damit haben wir den Trainingsprozess dieser beiden Markov-Modelle explizit \
durchgef\[UDoubleDot]hrt und k\[ODoubleDot]nnen die fertigen \
Wahrscheinlichkeitsmodelle im n\[ADoubleDot]chsten Teil zur Bewertung von \
Sequenzen nutzen.\n\n",
 StyleBox["Teil 2",
  FontWeight->"Bold"],
 "\nUm einsch\[ADoubleDot]tzen zu k\[ODoubleDot]nnen, ob diese beiden \
Modellzweige tats\[ADoubleDot]chlich systematisch und verl\[ADoubleDot]sslich \
CpG-Inseln von anderen Segmenten unterscheiden k\[ODoubleDot]nnen \
(Modellvalidierung), verwenden wir nun annotierte Daten des Segments B aus \
dem Chromosom 19. Auf diese Weise k\[ODoubleDot]nnen wir die (modellabh\
\[ADoubleDot]ngigen) Scores solcher Sequenzsegmente berechnen und \
\[UDoubleDot]berpr\[UDoubleDot]fen, ob die Werte mit der Annotation \
korrelieren. Dazu ben\[ODoubleDot]tigen wir als Erstes eine Funktion, die den \
Score auf der Grundlage der in Teil 1 durch Training gewonnenen \
\[Beta]-Matrix aus einer gegebenen Sequenz berechnet. Diese Funktion teilt \
die Sequenz in \[UDoubleDot]berlappende Paare, entnimmt der Matrix den \
jeweils zugeh\[ODoubleDot]rigen \[Beta]-Wert, addiert diese Werte \
\[UDoubleDot]ber die gesamte Sequenz und dividiert durch die Sequenzl\
\[ADoubleDot]nge."
}], "Text",
 CellChangeTimes->{{3.674629812969494*^9, 3.6746298251245117`*^9}, {
  3.674629908571637*^9, 3.674629946281694*^9}, {3.6774934728166656`*^9, 
  3.6774934816618814`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"extractScore", "[", "segX_", "]"}], ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"tmp1", ",", "tmp2"}], "}"}], ",", " ", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"tmp1", " ", "=", " ", 
      RowBox[{"Partition", "[", 
       RowBox[{"segX", ",", "2", ",", "1"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"tmp2", " ", "=", " ", 
      RowBox[{"Map", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"Position", "[", 
           RowBox[{"baseX", ",", "#"}], "]"}], "[", 
          RowBox[{"[", 
           RowBox[{"1", ",", "1"}], "]"}], "]"}], "&"}], ",", "tmp1"}], 
       "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"Plus", "@@", 
       RowBox[{"Map", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"Part", "[", 
           RowBox[{"betaValues", ",", "#"}], "]"}], "&"}], ",", "tmp2"}], 
        "]"}]}], "/", 
      RowBox[{"Length", "[", "tmp2", "]"}]}]}]}], "]"}]}]], "Input"],

Cell[TextData[{
 "Nun k\[ODoubleDot]nnen wir die CpG-Inseln des Segments B aus einer \
Ausgabedatei des Programms ",
 StyleBox["CpG island searcher",
  FontSlant->"Italic"],
 " einlesen und eine entsprechende Liste von Scores berechnen:"
}], "Text",
 CellChangeTimes->{{3.6746299656817245`*^9, 3.6746299861977577`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"CpG", "=", 
   RowBox[{"ReadList", "[", 
    RowBox[{
    "\"\<HU19B_CpG_Islands.txt\>\"", ",", "Character", ",", "1500000", ",", 
     RowBox[{"RecordLists", "\[Rule]", " ", "True"}], ",", 
     RowBox[{"RecordSeparators", "\[Rule]", " ", 
      RowBox[{"{", 
       RowBox[{"\"\<\\r\\n\>\"", ",", "\"\<\\n\>\"", ",", "\"\<\\r\>\""}], 
       "}"}]}]}], "]"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"scorePlus19", "=", 
   RowBox[{"Map", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"extractScore", "[", "#", "]"}], "&"}], ",", "CpG"}], "]"}]}], 
  ";"}]], "Input"],

Cell["\<\
Aus diesen Scores l\[ADoubleDot]sst sich ein Histogramm erstellen, das (mit \
einem Binning \[Dash] also einer S\[ADoubleDot]ulenbreite \[Dash] von 0.05) \
angibt, wie h\[ADoubleDot]ufig ein bestimmtes Score-Intervall auftritt:\
\>", "Text",
 CellChangeTimes->{{3.6746300011427794`*^9, 3.6746300502598524`*^9}, {
  3.6775646982292385`*^9, 3.6775647021604457`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"h19Plus", "=", "\n", 
   RowBox[{"Histogram", "[", 
    RowBox[{"scorePlus19", ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Min", "[", "scorePlus19", "]"}], ",", 
       RowBox[{"Max", "[", "scorePlus19", "]"}], ",", "0.05"}], "}"}], ",", 
     RowBox[{"ChartStyle", "\[Rule]", "Red"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.568715277921875*^9, 3.56871528340625*^9}, {
   3.56871545671875*^9, 3.568715472328125*^9}, {3.5687156316875*^9, 
   3.56871564584375*^9}, {3.56871568009375*^9, 3.568715687625*^9}, {
   3.568715725703125*^9, 3.568715737578125*^9}, {3.56871577275*^9, 
   3.568715777609375*^9}, {3.56871580821875*^9, 3.56871581203125*^9}, 
   3.574160802390625*^9}],

Cell[TextData[{
 "Dabei haben wir die Grafikausgabe zun\[ADoubleDot]chst \
unterdr\[UDoubleDot]ckt und das Histogramm nur in einer Variablen (",
 StyleBox["h19Plus",
  FontWeight->"Bold"],
 ") abgelegt. F\[UDoubleDot]r die Sequenzen ohne CpG-Inseln verfahren wir \
genauso und erhalten ein zweites Histogramm (",
 StyleBox["h19Minus",
  FontWeight->"Bold"],
 "). Um sicherzustellen, dass die Verteilung der Scores nicht durch die \
unterschiedlichen L\[ADoubleDot]ngenverteilungen der hier betrachteten zwei \
Modellzweige beeinflusst wird, werden Segmente aus den nicht als CpG-Inseln \
annotierten Daten ausgew\[ADoubleDot]hlt, die in ihrer \
L\[ADoubleDot]ngenverteilung den CpG-Inseln gleichen."
}], "Text",
 CellChangeTimes->{{3.674630109832941*^9, 3.6746301185939536`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"dist", "=", 
   RowBox[{"Map", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Length", "[", "#", "]"}], "&"}], ",", "CpG"}], "]"}]}], 
  ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"pos", "=", 
   RowBox[{
    RowBox[{"Partition", "[", 
     RowBox[{
      RowBox[{"FoldList", "[", 
       RowBox[{"Plus", ",", "0", ",", "dist"}], "]"}], ",", "2", ",", "1"}], 
     "]"}], "/.", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"n1_", ",", "n2_"}], "}"}], "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"n1", "+", "1"}], ",", "n2"}], "}"}]}]}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"NoCpG", "=", 
   RowBox[{
    RowBox[{"ReadList", "[", 
     RowBox[{
     "\"\<HU19B_NoCpG_Islands.txt\>\"", ",", "Character", ",", "1500000", ",", 
      RowBox[{"RecordLists", "\[Rule]", "True"}], ",", 
      RowBox[{"RecordSeparators", "\[Rule]", " ", 
       RowBox[{"{", 
        RowBox[{"\"\<\\r\\n\>\"", ",", "\"\<\\n\>\"", ",", "\"\<\\r\>\""}], 
        "}"}]}]}], "]"}], "//", "Flatten"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"scoreMinus19", "=", 
   RowBox[{"Map", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"extractScore", "[", 
       RowBox[{"Take", "[", 
        RowBox[{"NoCpG", ",", "#"}], "]"}], "]"}], "&"}], ",", "pos"}], 
    "]"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"h19Minus", "=", 
   RowBox[{"Histogram", "[", 
    RowBox[{"scoreMinus19", ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Min", "[", "scoreMinus19", "]"}], ",", 
       RowBox[{"Max", "[", "scoreMinus19", "]"}], ",", "0.05"}], "}"}], ",", 
     RowBox[{"ChartStyle", "\[Rule]", "Blue"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.568715550203125*^9, 3.568715569484375*^9}, {
   3.568715827203125*^9, 3.568715830359375*^9}, {3.570521828441559*^9, 
   3.57052183283224*^9}, 3.5741608581875*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{"h19Plus", ",", "h19Minus", ",", 
   RowBox[{"Frame", "\[Rule]", "True"}], ",", 
   RowBox[{"Axes", "\[Rule]", "False"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "0.4"}], ",", "0.3"}], "}"}], ",", "All"}], "}"}]}]}], 
  "]"}]], "Input",
 CellChangeTimes->{
  3.5687158465*^9, {3.5704538795109363`*^9, 3.570453880010914*^9}}],

Cell[BoxData[
 GraphicsBox[{{
    {RGBColor[1, 0, 0], EdgeForm[{Opacity[0.644], Thickness[Small]}], {}, 
     {RGBColor[1, 0, 0], EdgeForm[{Opacity[0.644], Thickness[Small]}], 
      TagBox[
       TooltipBox[
        TagBox[
         DynamicBox[{
           FEPrivate`If[
            CurrentValue["MouseOver"], 
            EdgeForm[{
              GrayLevel[0.5], 
              AbsoluteThickness[1.5], 
              Opacity[0.66]}], {}, {}], 
           
           RectangleBox[{-0.1074420741177362, 0}, {-0.05744207411773619, 3}, 
            "RoundingRadius" -> 0]},
          
          ImageSizeCache->{{157.00251895698327`, 179.68327697447597`}, {
           84.09621193485246, 85.66677443371664}}],
         StatusArea[#, 3]& ,
         TagBoxNote->"3"],
        StyleBox["3", {}, StripOnInput -> False]],
       Annotation[#, 
        Style[3, {}], "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        TagBox[
         DynamicBox[{
           FEPrivate`If[
            CurrentValue["MouseOver"], 
            EdgeForm[{
              GrayLevel[0.5], 
              AbsoluteThickness[1.5], 
              Opacity[0.66]}], {}, {}], 
           
           RectangleBox[{-0.05744207411773619, 0}, {-0.007442074117736189, 
             55}, "RoundingRadius" -> 0]},
          
          ImageSizeCache->{{179.18327697447597`, 201.86403499196868`}, {
           65.53979528787346, 85.66677443371664}}],
         StatusArea[#, 55]& ,
         TagBoxNote->"55"],
        StyleBox["55", {}, StripOnInput -> False]],
       Annotation[#, 
        Style[55, {}], "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        TagBox[
         DynamicBox[{
           FEPrivate`If[
            CurrentValue["MouseOver"], 
            EdgeForm[{
              GrayLevel[0.5], 
              AbsoluteThickness[1.5], 
              Opacity[0.66]}], {}, {}], 
           
           RectangleBox[{-0.007442074117736189, 0}, {
            0.04255792588226383, 521}, "RoundingRadius" -> 0]},
          ImageSizeCache->{{201.36403499196868`, 
           224.04479300946142`}, {-100.75424620236144`, 85.66677443371664}}],
         StatusArea[#, 521]& ,
         TagBoxNote->"521"],
        StyleBox["521", {}, StripOnInput -> False]],
       Annotation[#, 
        Style[521, {}], "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        TagBox[
         DynamicBox[{
           FEPrivate`If[
            CurrentValue["MouseOver"], 
            EdgeForm[{
              GrayLevel[0.5], 
              AbsoluteThickness[1.5], 
              Opacity[0.66]}], {}, {}], 
           
           RectangleBox[{0.04255792588226383, 0}, {0.09255792588226382, 395}, 
            "RoundingRadius" -> 0]},
          
          ImageSizeCache->{{223.54479300946142`, 
           246.22555102695412`}, {-55.79062125006617, 85.66677443371664}}],
         StatusArea[#, 395]& ,
         TagBoxNote->"395"],
        StyleBox["395", {}, StripOnInput -> False]],
       Annotation[#, 
        Style[395, {}], "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        TagBox[
         DynamicBox[{
           FEPrivate`If[
            CurrentValue["MouseOver"], 
            EdgeForm[{
              GrayLevel[0.5], 
              AbsoluteThickness[1.5], 
              Opacity[0.66]}], {}, {}], 
           
           RectangleBox[{0.09255792588226382, 0}, {0.1425579258822638, 273}, 
            "RoundingRadius" -> 0]},
          
          ImageSizeCache->{{245.72555102695412`, 
           268.4063090444468}, {-12.254412962923112`, 85.66677443371664}}],
         StatusArea[#, 273]& ,
         TagBoxNote->"273"],
        StyleBox["273", {}, StripOnInput -> False]],
       Annotation[#, 
        Style[273, {}], "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        TagBox[
         DynamicBox[{
           FEPrivate`If[
            CurrentValue["MouseOver"], 
            EdgeForm[{
              GrayLevel[0.5], 
              AbsoluteThickness[1.5], 
              Opacity[0.66]}], {}, {}], 
           
           RectangleBox[{0.1425579258822638, 0}, {0.19255792588226384`, 88}, 
            "RoundingRadius" -> 0]},
          
          ImageSizeCache->{{267.9063090444468, 290.58706706193954`}, {
           53.76360780036756, 85.66677443371664}}],
         StatusArea[#, 88]& ,
         TagBoxNote->"88"],
        StyleBox["88", {}, StripOnInput -> False]],
       Annotation[#, 
        Style[88, {}], "Tooltip"]& ]}, {}, {}}, {{}, {}, {}, {}, {}, {}}}, {
    {RGBColor[0, 0, 1], EdgeForm[{Opacity[0.623], Thickness[Small]}], {}, 
     {RGBColor[0, 0, 1], EdgeForm[{Opacity[0.623], Thickness[Small]}], 
      TagBox[
       TooltipBox[
        TagBox[
         DynamicBox[{
           FEPrivate`If[
            CurrentValue["MouseOver"], 
            EdgeForm[{
              GrayLevel[0.5], 
              AbsoluteThickness[1.5], 
              Opacity[0.66]}], {}, {}], 
           
           RectangleBox[{-0.49148238043487935`, 0}, {-0.44148238043487936`, 
             1}, "RoundingRadius" -> 0]},
          
          ImageSizeCache->{{-13.363583110703274`, 9.317174906789404}, {
           84.80992026742858, 85.66677443371664}}],
         StatusArea[#, 1]& ,
         TagBoxNote->"1"],
        StyleBox["1", {}, StripOnInput -> False]],
       Annotation[#, 
        Style[1, {}], "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        TagBox[
         DynamicBox[{
           FEPrivate`If[
            CurrentValue["MouseOver"], 
            EdgeForm[{
              GrayLevel[0.5], 
              AbsoluteThickness[1.5], 
              Opacity[0.66]}], {}, {}], 
           
           RectangleBox[{-0.3914823804348794, 0}, {-0.34148238043487933`, 1}, 
            "RoundingRadius" -> 0]},
          
          ImageSizeCache->{{30.99793292428211, 53.678690941774846`}, {
           84.80992026742858, 85.66677443371664}}],
         StatusArea[#, 1]& ,
         TagBoxNote->"1"],
        StyleBox["1", {}, StripOnInput -> False]],
       Annotation[#, 
        Style[1, {}], "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        TagBox[
         DynamicBox[{
           FEPrivate`If[
            CurrentValue["MouseOver"], 
            EdgeForm[{
              GrayLevel[0.5], 
              AbsoluteThickness[1.5], 
              Opacity[0.66]}], {}, {}], 
           
           RectangleBox[{-0.34148238043487933`, 0}, {-0.29148238043487934`, 
             20}, "RoundingRadius" -> 0]},
          
          ImageSizeCache->{{53.178690941774846`, 75.85944895926755}, {
           78.02969110795549, 85.66677443371664}}],
         StatusArea[#, 20]& ,
         TagBoxNote->"20"],
        StyleBox["20", {}, StripOnInput -> False]],
       Annotation[#, 
        Style[20, {}], "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        TagBox[
         DynamicBox[{
           FEPrivate`If[
            CurrentValue["MouseOver"], 
            EdgeForm[{
              GrayLevel[0.5], 
              AbsoluteThickness[1.5], 
              Opacity[0.66]}], {}, {}], 
           
           RectangleBox[{-0.29148238043487934`, 0}, {-0.24148238043487935`, 
             95}, "RoundingRadius" -> 0]},
          
          ImageSizeCache->{{75.35944895926755, 98.04020697676025}, {
           51.26562863635116, 85.66677443371664}}],
         StatusArea[#, 95]& ,
         TagBoxNote->"95"],
        StyleBox["95", {}, StripOnInput -> False]],
       Annotation[#, 
        Style[95, {}], "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        TagBox[
         DynamicBox[{
           FEPrivate`If[
            CurrentValue["MouseOver"], 
            EdgeForm[{
              GrayLevel[0.5], 
              AbsoluteThickness[1.5], 
              Opacity[0.66]}], {}, {}], 
           
           RectangleBox[{-0.24148238043487935`, 0}, {-0.1914823804348793, 
             164}, "RoundingRadius" -> 0]},
          ImageSizeCache->{{97.54020697676025, 120.22096499425298`}, {
           26.642691162475174`, 85.66677443371664}}],
         StatusArea[#, 164]& ,
         TagBoxNote->"164"],
        StyleBox["164", {}, StripOnInput -> False]],
       Annotation[#, 
        Style[164, {}], "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        TagBox[
         DynamicBox[{
           FEPrivate`If[
            CurrentValue["MouseOver"], 
            EdgeForm[{
              GrayLevel[0.5], 
              AbsoluteThickness[1.5], 
              Opacity[0.66]}], {}, {}], 
           
           RectangleBox[{-0.1914823804348793, 0}, {-0.14148238043487932`, 
             371}, "RoundingRadius" -> 0]},
          
          ImageSizeCache->{{119.72096499425298`, 
           142.40172301174567`}, {-47.22612125915278, 85.66677443371664}}],
         StatusArea[#, 371]& ,
         TagBoxNote->"371"],
        StyleBox["371", {}, StripOnInput -> False]],
       Annotation[#, 
        Style[371, {}], "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        TagBox[
         DynamicBox[{
           FEPrivate`If[
            CurrentValue["MouseOver"], 
            EdgeForm[{
              GrayLevel[0.5], 
              AbsoluteThickness[1.5], 
              Opacity[0.66]}], {}, {}], 
           
           RectangleBox[{-0.14148238043487932`, 0}, {-0.09148238043487933, 
             498}, "RoundingRadius" -> 0]},
          
          ImageSizeCache->{{141.90172301174567`, 
           164.58248102923838`}, {-92.54660037773611, 85.66677443371664}}],
         StatusArea[#, 498]& ,
         TagBoxNote->"498"],
        StyleBox["498", {}, StripOnInput -> False]],
       Annotation[#, 
        Style[498, {}], "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        TagBox[
         DynamicBox[{
           FEPrivate`If[
            CurrentValue["MouseOver"], 
            EdgeForm[{
              GrayLevel[0.5], 
              AbsoluteThickness[1.5], 
              Opacity[0.66]}], {}, {}], 
           
           RectangleBox[{-0.09148238043487933, 0}, {-0.04148238043487934, 
             174}, "RoundingRadius" -> 0]},
          
          ImageSizeCache->{{164.08248102923838`, 186.7632390467311}, {
           23.074149499594597`, 85.66677443371664}}],
         StatusArea[#, 174]& ,
         TagBoxNote->"174"],
        StyleBox["174", {}, StripOnInput -> False]],
       Annotation[#, 
        Style[174, {}], 
        "Tooltip"]& ]}, {}, {}}, {{}, {}, {}, {}, {}, {}, {}, {}}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->False,
  AxesLabel->{None, None},
  AxesOrigin->{-0.1134420741177362, 0},
  Frame->True,
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  PlotRange->{{-0.4, 0.3}, All},
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.67757151392301*^9}]
}, Open  ]],

Cell[TextData[{
 "Mit dem Befehl ",
 StyleBox["Show",
  FontWeight->"Bold"],
 " kann man diese beiden Histogramme gemeinsam darstellen.Das Resultat hatten \
wir bereits in Abb. 2.39 in Kap. 2.7.2 kennengelernt.\n\n",
 StyleBox["Teil 3",
  FontWeight->"Bold"],
 "\nDer dritte Teil dieses ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "-Exkurses vollf\[UDoubleDot]hrt den Schritt von Markov- zu \
Hidden-Markov-Modellen. Dabei werden wir eine extrem einfache Form von HMM \
diskutieren, n\[ADoubleDot]mlich f\[UDoubleDot]r einen zweielementigen \
HMM-Zustandsraum. Dadurch wird die Parametersch\[ADoubleDot]tzung fast \
trivial. Letztlich ist dazu nur nachzuz\[ADoubleDot]hlen, wie viele Symbole \
des Chromosoms innerhalb und au\[SZ]erhalb der CpG-Inseln liegen und wie h\
\[ADoubleDot]ufig die \[CapitalUDoubleDot]berg\[ADoubleDot]nge in CpG-Inseln \
hinein und aus CpG-Inseln heraus sind. W\[ADoubleDot]hrend erstere Werte der \
Zahl der Symbole in den beiden annotierten Dateien entsprechen, erh\
\[ADoubleDot]lt man letztere Parameter einfach aus der Zahl der CpG-Inseln \
selbst. Die Parameterbestimmung wird nun erneut am Segment A des menschlichen \
Chromosoms 19 durchgef\[UDoubleDot]hrt. Man hat als Zahl von Symbolen in \
CpG-Inseln:"
}], "Text",
 CellChangeTimes->{{3.674630175714043*^9, 3.674630201697082*^9}, {
  3.674630276737197*^9, 3.6746302776471987`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"CpG19", "=", 
   RowBox[{"ReadList", "[", 
    RowBox[{"\"\<HU19A_CpG_Islands.txt\>\"", ",", "Character", ",", 
     RowBox[{"RecordLists", "\[Rule]", "True"}], ",", 
     RowBox[{"RecordSeparators", "\[Rule]", " ", 
      RowBox[{"{", 
       RowBox[{"\"\<\\r\\n\>\"", ",", "\"\<\\n\>\"", ",", "\"\<\\r\>\""}], 
       "}"}]}]}], "]"}]}], ";"}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"sizeCpG", "=", 
  RowBox[{"Total", "[", 
   RowBox[{"Map", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Count", "[", 
       RowBox[{
        RowBox[{"Flatten", "[", "CpG19", "]"}], ",", "#"}], "]"}], "&"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "\"\<A\>\"", ",", "\"\<G\>\"", ",", "\"\<C\>\"", ",", "\"\<T\>\""}], 
      "}"}]}], "]"}], "]"}]}]], "Input"],

Cell[BoxData["1626935"], "Output",
 CellChangeTimes->{3.677571514593811*^9}]
}, Open  ]],

Cell[TextData[{
 "Als N\[ADoubleDot]chstes bestimmen wir nun die Zahl der CpG-Inseln im \
Segment A. Dazu verwenden wir Informationen aus der Ausgabedatei von ",
 StyleBox["CpG island searcher",
  FontSlant->"Italic"],
 ". Diese Datei wird eingelesen und der Dateibeginn wird ausgegeben."
}], "Text",
 CellChangeTimes->{{3.674630302007234*^9, 3.674630343668298*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"CpG19Log", "=", 
   RowBox[{"ReadList", "[", 
    RowBox[{"\"\<HU19A_CpG_logfile.txt\>\"", ",", "Word"}], "]"}]}], 
  ";"}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Take", "[", 
  RowBox[{"CpG19Log", ",", "50"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"CpG\"\>", ",", "\<\"island\"\>", ",", "\<\"searcher\"\>", 
   ",", "\<\"command\"\>", ",", "\<\"line\"\>", ",", "\<\"version\"\>", 
   ",", "\<\"Ver\"\>", ",", "\<\"1.3\"\>", ",", "\<\"released\"\>", 
   ",", "\<\"05/21/03\"\>", ",", "\<\"by\"\>", ",", "\<\"Takai\"\>", 
   ",", "\<\"D.\"\>", ",", "\<\"&\"\>", ",", "\<\"Jones\"\>", 
   ",", "\<\"PA.\"\>", ",", "\<\"Selected\"\>", ",", "\<\"lower\"\>", 
   ",", "\<\"limits:\"\>", ",", "\<\"%GC=55,\"\>", 
   ",", "\<\"ObsCpG/ExpCpG=0.65,\"\>", ",", "\<\"Length=500\"\>", 
   ",", "\<\"HU19A.cs,\"\>", ",", "\<\"CpG\"\>", ",", "\<\"island\"\>", 
   ",", "\<\"1,\"\>", ",", "\<\"start=10146,\"\>", ",", "\<\"end=11639,\"\>", 
   ",", "\<\"%GC=64.5,\"\>", ",", "\<\"ObsCpG/ExpCpG=0.825,\"\>", 
   ",", "\<\"Length=1494\"\>", ",", "\<\"HU19A.cs,\"\>", ",", "\<\"CpG\"\>", 
   ",", "\<\"island\"\>", ",", "\<\"2,\"\>", ",", "\<\"start=33052,\"\>", 
   ",", "\<\"end=33603,\"\>", ",", "\<\"%GC=55,\"\>", 
   ",", "\<\"ObsCpG/ExpCpG=0.873,\"\>", ",", "\<\"Length=552\"\>", 
   ",", "\<\"HU19A.cs,\"\>", ",", "\<\"CpG\"\>", ",", "\<\"island\"\>", 
   ",", "\<\"3,\"\>", ",", "\<\"start=185969,\"\>", 
   ",", "\<\"end=187182,\"\>", ",", "\<\"%GC=64.4,\"\>", 
   ",", "\<\"ObsCpG/ExpCpG=0.776,\"\>", ",", "\<\"Length=1214\"\>", 
   ",", "\<\"HU19A.cs,\"\>"}], "}"}]], "Output",
 CellChangeTimes->{3.6775715146250105`*^9}]
}, Open  ]],

Cell["\<\
Eine der vielen M\[ODoubleDot]glichkeiten, diesen Parameter zu extrahieren, \
besteht in der Identifikation des Strings \[OpenCurlyDoubleQuote]start=\
\[CloseCurlyDoubleQuote]. Es ist klar, dass sich auf dieselbe Weise z.B. eine \
Liste aller Nukleotidpositionen erstellen lie\[SZ]e, die den Anfang einer \
CpG-Insel markieren.\
\>", "Text",
 CellChangeTimes->{{3.674630385031361*^9, 3.674630415417406*^9}, 
   3.677493661026397*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"startList", "=", 
   RowBox[{"Flatten", "[", 
    RowBox[{"Position", "[", 
     RowBox[{"CpG19Log", ",", 
      RowBox[{"n1_String", "/;", 
       RowBox[{"StringMatchQ", "[", 
        RowBox[{"n1", ",", "\"\<start=*\>\""}], "]"}]}]}], "]"}], "]"}]}], 
  ";"}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"numCpG", "=", 
  RowBox[{"Length", "[", "startList", "]"}]}]], "Input"],

Cell[BoxData["1616"], "Output",
 CellChangeTimes->{3.6775715146406107`*^9}]
}, Open  ]],

Cell["Dasselbe Ergebnis liefert eine einfache Dimensionsabfrage:", "Text",
 CellChangeTimes->{{3.6746304400904446`*^9, 3.674630456064468*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Dimensions", "[", "CpG19", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", "1616", "}"}]], "Output",
 CellChangeTimes->{3.677571514656211*^9}]
}, Open  ]],

Cell[TextData[{
 "Die anderen Parameter erh\[ADoubleDot]lt man durch folgende \
\[CapitalUDoubleDot]berlegung. Betrachten wir ",
 StyleBox["N",
  FontSlant->"Italic"],
 " CpG-Inseln mit L\[ADoubleDot]ngen ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["L", "1"], TraditionalForm]]],
 ", ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["L", "2"], TraditionalForm]]],
 ", . . . , ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["L", "N"], TraditionalForm]]],
 " und \[CapitalUDoubleDot]berg\[ADoubleDot]nge innerhalb der CpG-Inseln \
(Wahrscheinlichkeit ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["p", "++"], TraditionalForm]]],
 ") und aus CpG-Inseln heraus (Wahrscheinlichkeit ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["p", 
    RowBox[{"+", "-"}]], TraditionalForm]]],
 "). Dann hat man\n\n",
 Cell[BoxData[
  FormBox[
   SubscriptBox["p", "++"], TraditionalForm]]],
 "=",
 Cell[BoxData[
  FormBox[
   FractionBox[
    RowBox[{
     RowBox[{"\[Sum]", 
      SubscriptBox["L", "i"]}], "-", "N"}], 
    RowBox[{"\[Sum]", 
     SubscriptBox["L", "i"]}]], TraditionalForm]]],
 ", ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["p", 
    RowBox[{"+", "-"}]], TraditionalForm]]],
 "=",
 Cell[BoxData[
  FormBox[
   FractionBox["N", 
    RowBox[{"\[Sum]", 
     SubscriptBox["L", "i"]}]], TraditionalForm]]],
 ".\n\nDie Umsetzung in ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " ist gegeben durch:"
}], "Text",
 CellChangeTimes->{{3.6746305260935707`*^9, 3.674630610359701*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"pPlusPlus", "=", 
  RowBox[{"N", "[", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"sizeCpG", "-", "numCpG"}], ")"}], "/", "sizeCpG"}], 
   "]"}]}]], "Input"],

Cell[BoxData["0.9990067212273385`"], "Output",
 CellChangeTimes->{3.677571514671811*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"pPlusMinus", "=", 
  RowBox[{"N", "[", 
   RowBox[{"numCpG", "/", "sizeCpG"}], "]"}]}]], "Input"],

Cell[BoxData["0.000993278772661477`"], "Output",
 CellChangeTimes->{3.677571514687411*^9}]
}, Open  ]],

Cell["\<\
\[CapitalUDoubleDot]ber die \[CapitalUDoubleDot]bergangswahrscheinlichkeiten \
hinaus ben\[ODoubleDot]tigen wir noch die relativen H\[ADoubleDot]ufigkeiten \
der Einzelsymbole als Emissionswahrscheinlichkeiten des HMM:\
\>", "Text",
 CellChangeTimes->{{3.6746306350367374`*^9, 3.6746306460337563`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"matrixX0", " ", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"Map", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"Count", "[", 
        RowBox[{
         RowBox[{"Flatten", "[", "CpG19", "]"}], ",", "#"}], "]"}], "&"}], 
      " ", ",", 
      RowBox[{"{", 
       RowBox[{
       "\"\<A\>\"", ",", "\"\<G\>\"", ",", "\"\<C\>\"", ",", "\"\<T\>\""}], 
       "}"}]}], "]"}], "/", " ", "sizeCpG"}], "//", "N", " "}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0.18235639407843582`", ",", "0.3181958713777748`", ",", 
   "0.3160070930922256`", ",", "0.18344064145156383`"}], "}"}]], "Output",
 CellChangeTimes->{3.6775715151242113`*^9}]
}, Open  ]],

Cell[TextData[{
 "Die Trainingsdaten ohne CpG-Inseln durchlaufen denselben Prozess. Das \
Ergebnis ist eine Liste ",
 StyleBox["matrixY0",
  FontWeight->"Bold"],
 ", die mit einer Initialisierung und der Liste ",
 StyleBox["matrixX0",
  FontWeight->"Bold"],
 " zur Matrix der Emissionswahrscheinlichkeiten zusammengef\[UDoubleDot]gt \
werden kann (Funktion ",
 StyleBox["emission",
  FontWeight->"Bold"],
 "). Die Parameter ",
 StyleBox["pMinusMinus",
  FontWeight->"Bold"],
 " etc. werden in eine Funktion transition eingetragen."
}], "Text",
 CellChangeTimes->{
  3.6746306927148256`*^9, {3.674630779179957*^9, 3.674630783412963*^9}, 
   3.6746462283453655`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"NoCpG19", "=", 
   RowBox[{"ReadList", "[", 
    RowBox[{
    "\"\<HU19A_NoCpG_Islands.txt\>\"", ",", "Character", ",", "15000000", ",", 
     RowBox[{"RecordLists", "\[Rule]", "True"}], ",", 
     RowBox[{"RecordSeparators", "\[Rule]", " ", 
      RowBox[{"{", 
       RowBox[{"\"\<\\r\\n\>\"", ",", "\"\<\\n\>\"", ",", "\"\<\\r\>\""}], 
       "}"}]}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.570454380735523*^9, 3.570454440029362*^9}, {
   3.5704544762306337`*^9, 3.570454506854066*^9}, 3.57416110171875*^9, {
   3.574162264359375*^9, 3.57416226496875*^9}, {3.574164269578125*^9, 
   3.574164292546875*^9}},
 FontColor->GrayLevel[0],
 Background->RGBColor[0.87, 0.94, 1]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Dimensions", 
  StyleBox["[", "Code"], 
  RowBox[{"Flatten", "[", "NoCpG19", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.570453999739406*^9, 3.5704540416278863`*^9}},
 FontColor->GrayLevel[0],
 Background->RGBColor[0.87, 0.94, 1]],

Cell[BoxData[
 RowBox[{"{", "15000000", "}"}]], "Output",
 CellChangeTimes->{3.677571517947817*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"sizeNoCpG2", " ", "=", "  ", 
  RowBox[{"Total", "[", 
   RowBox[{"Map", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Count", "[", 
       RowBox[{
        RowBox[{"Flatten", "[", "NoCpG19", "]"}], ",", "#"}], "]"}], "&"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
      "\"\<A\>\"", ",", "\"\<G\>\"", ",", "\"\<C\>\"", ",", "\"\<T\>\""}], 
      "}"}]}], "]"}], "]"}], " "}]], "Input",
 CellChangeTimes->{3.574162146625*^9},
 FontColor->GrayLevel[0],
 Background->RGBColor[0.87, 0.94, 1]],

Cell[BoxData["15000000"], "Output",
 CellChangeTimes->{3.6775715224592247`*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{
   RowBox[{"sizeNoCpG", " ", "=", "26265891"}], ";"}], " "}]], "Input",
 CellChangeTimes->{{3.5704545227126284`*^9, 3.570454539039918*^9}, {
  3.574161561640625*^9, 3.574161564859375*^9}},
 FontColor->GrayLevel[0],
 Background->RGBColor[0.87, 0.94, 1]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"pMinusMinus", " ", "=", " ", 
  RowBox[{"N", "[", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"sizeNoCpG", " ", "-", "numCpG"}], ")"}], "/", "sizeNoCpG"}], 
   "]"}]}]], "Input",
 FontColor->GrayLevel[0],
 Background->RGBColor[0.87, 0.94, 1]],

Cell[BoxData["0.9999384753405091`"], "Output",
 CellChangeTimes->{3.677571522506025*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"pMinusPlus", " ", "=", " ", 
  RowBox[{"N", "[", 
   RowBox[{"numCpG", "/", "sizeNoCpG"}], "]"}]}]], "Input",
 FontColor->GrayLevel[0],
 Background->RGBColor[0.87, 0.94, 1]],

Cell[BoxData["0.00006152465949089638`"], "Output",
 CellChangeTimes->{3.677571522537225*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{"matrixY0", " ", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"Map", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Count", "[", 
         RowBox[{
          RowBox[{"Flatten", "[", "NoCpG19", "]"}], ",", "#"}], "]"}], "&"}], 
       " ", ",", 
       RowBox[{"{", 
        RowBox[{
        "\"\<A\>\"", ",", "\"\<G\>\"", ",", "\"\<C\>\"", ",", "\"\<T\>\""}], 
        "}"}]}], "]"}], "/", " ", "sizeNoCpG2"}], "//", "N", 
    " "}]}]}]], "Input",
 CellChangeTimes->{3.574162162625*^9},
 FontColor->GrayLevel[0],
 Background->RGBColor[0.87, 0.94, 1]],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0.24843193333333333`", ",", "0.252225`", ",", "0.25139106666666666`", ",", 
   "0.247952`"}], "}"}]], "Output",
 CellChangeTimes->{3.6775715269832325`*^9}]
}, Open  ]],

Cell["\<\
Als n\[ADoubleDot]chstes k\[ODoubleDot]nnen wir diese Parameter zur \
Definition des Hidden-Markov-Modells zusammenf\[UDoubleDot]gen:\
\>", "Text",
 CellChangeTimes->{{3.674630932717183*^9, 3.6746309480632057`*^9}},
 FontColor->GrayLevel[0],
 Background->RGBColor[0.87, 0.94, 1]],

Cell[BoxData[
 RowBox[{
  RowBox[{"state", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{"\"\<0\>\"", ",", "\"\<-\>\"", ",", " ", "\"\<+\>\""}], "}"}]}], 
  ";"}]], "Input",
 FontColor->GrayLevel[0],
 Background->RGBColor[0.87, 0.94, 1]],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"observation", " ", "=", " ", 
    RowBox[{"{", 
     RowBox[{
     "\"\<A\>\"", ",", " ", "\"\<G\>\"", ",", " ", "\"\<C\>\"", ",", " ", 
      "\"\<T\>\""}], "}"}]}], ";"}], " "}]], "Input",
 FontColor->GrayLevel[0],
 Background->RGBColor[0.87, 0.94, 1]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"emTab", " ", "=", " ", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", " ", "matrixY0",
     ",", "matrixX0"}], "}"}]}]], "Input",
 FontColor->GrayLevel[0],
 Background->RGBColor[0.87, 0.94, 1]],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "0.24843193333333333`", ",", "0.252225`", ",", "0.25139106666666666`", 
     ",", "0.247952`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "0.18235639407843582`", ",", "0.3181958713777748`", ",", 
     "0.3160070930922256`", ",", "0.18344064145156383`"}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.677571527030033*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"emission", "[", 
   RowBox[{"z1_", ",", "z2_"}], "]"}], ":=", " ", 
  RowBox[{"emTab", "[", 
   RowBox[{"[", 
    RowBox[{
     RowBox[{
      RowBox[{"Flatten", "[", 
       RowBox[{"Position", "[", 
        RowBox[{"state", ",", "z1"}], "]"}], "]"}], "[", 
      RowBox[{"[", "1", "]"}], "]"}], ",", 
     RowBox[{
      RowBox[{"Flatten", "[", 
       RowBox[{"Position", "[", 
        RowBox[{"observation", ",", "z2"}], "]"}], "]"}], "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "]"}]}]], "Input",
 FontColor->GrayLevel[0],
 Background->RGBColor[0.87, 0.94, 1]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"emission", "[", 
  RowBox[{"\"\<+\>\"", ",", "\"\<T\>\""}], "]"}]], "Input",
 FontColor->GrayLevel[0],
 Background->RGBColor[0.87, 0.94, 1]],

Cell[BoxData["0.18344064145156383`"], "Output",
 CellChangeTimes->{3.677571527045633*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"probNoCpG", "=", " ", 
  RowBox[{"N", "[", 
   RowBox[{"sizeNoCpG", "/", 
    RowBox[{"(", 
     RowBox[{"sizeCpG", "+", "sizeNoCpG"}], ")"}]}], "]"}]}]], "Input",
 FontColor->GrayLevel[0],
 Background->RGBColor[0.87, 0.94, 1]],

Cell[BoxData["0.9416719195107731`"], "Output",
 CellChangeTimes->{3.6775715270612326`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"probCpG", "=", " ", 
  RowBox[{"N", "[", 
   RowBox[{"sizeCpG", "/", 
    RowBox[{"(", 
     RowBox[{"sizeCpG", "+", "sizeNoCpG"}], ")"}]}], "]"}]}]], "Input",
 FontColor->GrayLevel[0],
 Background->RGBColor[0.87, 0.94, 1]],

Cell[BoxData["0.05832808048922687`"], "Output",
 CellChangeTimes->{3.6775715270612326`*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"transition", "[", 
   RowBox[{"z1_", ",", "z2_"}], "]"}], ":=", " ", 
  RowBox[{"Switch", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"z1", ",", "z2"}], "}"}], ",", " ", "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{"\"\<-\>\"", ",", "\"\<-\>\""}], "}"}], ",", " ", "pMinusMinus", 
    ",", " ", "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{"\"\<-\>\"", ",", "\"\<+\>\""}], "}"}], ",", " ", "pMinusPlus", 
    ",", " ", "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{"\"\<+\>\"", ",", "\"\<+\>\""}], "}"}], ",", " ", "pPlusPlus", 
    ",", " ", "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{"\"\<+\>\"", ",", "\"\<-\>\""}], "}"}], ",", " ", "pPlusMinus", 
    ",", "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{"\"\<0\>\"", ",", " ", "\"\<+\>\""}], "}"}], ",", " ", "0.5", 
    ",", "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{"\"\<0\>\"", ",", " ", "\"\<-\>\""}], "}"}], ",", "0.5", ",", 
    "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{"\"\<0\>\"", ",", "\"\<0\>\""}], "}"}], ",", " ", "0.0", ",", 
    " ", "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{"\"\<+\>\"", ",", " ", "\"\<0\>\""}], "}"}], ",", " ", "0.0", 
    ",", " ", "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{"\"\<-\>\"", ",", " ", "\"\<0\>\""}], "}"}], ",", "0.0"}], 
   "]"}]}]], "Input",
 FontColor->GrayLevel[0],
 Background->RGBColor[0.87, 0.94, 1]],

Cell[TextData[StyleBox["Die Implementierung der Emissionswahrscheinlichkeiten \
wurde dabei nicht wie im Kasinobeispiel \[UDoubleDot]ber den Befehl Switch \
realisiert, sondern durch expliziten Zugriff auf die Elemente der oben \
bestimmten Matrix mit den Symbolh\[ADoubleDot]ufigkeiten.",
 FontColor->GrayLevel[0]]], "Text",
 CellChangeTimes->{{3.677564299957138*^9, 3.6775643179529705`*^9}, 
   3.677564368216259*^9},
 FontColor->GrayLevel[0],
 Background->RGBColor[0.87, 0.94, 1]],

Cell["\<\
Wie zuvor k\[ODoubleDot]nnen wir zuerst eine synthetische Testsequenz \
konstruieren, indem die 200ste CpG-Insel des Segments A aus Chromosom 19 in \
ein Sequenzst\[UDoubleDot]ck ohne CpG-Inseln eingesetzt wird.\
\>", "Text",
 CellChangeTimes->{{3.6746308162170115`*^9, 3.6746308205910177`*^9}, {
  3.674630857027071*^9, 3.674630864887082*^9}, {3.6746309754532475`*^9, 
  3.674630977126251*^9}, {3.6775642899419208`*^9, 3.677564296883933*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"CpG19", "=", 
   RowBox[{"ReadList", "[", 
    RowBox[{"\"\<HU19B_CpG_Islands.txt\>\"", ",", "Character", ",", 
     RowBox[{"RecordLists", "\[Rule]", "True"}], ",", 
     RowBox[{"RecordSeparators", "\[Rule]", " ", 
      RowBox[{"{", 
       RowBox[{"\"\<\\r\\n\>\"", ",", "\"\<\\n\>\"", ",", "\"\<\\r\>\""}], 
       "}"}]}]}], "]"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"segPlus", "=", 
   RowBox[{"CpG19", "[", 
    RowBox[{"[", "200", "]"}], "]"}]}], ";"}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Length", "[", "segPlus", "]"}]], "Input"],

Cell[BoxData["2316"], "Output",
 CellChangeTimes->{3.6775715272952332`*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"NoCpG19", "=", 
   RowBox[{
    RowBox[{"ReadList", "[", 
     RowBox[{
     "\"\<HU19B_NoCpG_Islands.txt\>\"", ",", "Character", ",", "100000", ",", 
      RowBox[{"RecordLists", "\[Rule]", "True"}], ",", 
      RowBox[{"RecordSeparators", "\[Rule]", " ", 
       RowBox[{"{", 
        RowBox[{"\"\<\\r\\n\>\"", ",", "\"\<\\n\>\"", ",", "\"\<\\r\>\""}], 
        "}"}]}]}], "]"}], "//", "Flatten"}]}], ";"}]], "Input",
 FontColor->GrayLevel[0],
 Background->RGBColor[0.87, 0.94, 1]],

Cell[BoxData[
 RowBox[{
  RowBox[{"segMinus", "=", 
   RowBox[{"Take", "[", 
    RowBox[{"NoCpG19", ",", 
     RowBox[{"{", 
      RowBox[{"60001", ",", "70000"}], "}"}]}], "]"}]}], ";"}]], "Input",
 FontColor->GrayLevel[0],
 Background->RGBColor[0.87, 0.94, 1]],

Cell[BoxData[
 RowBox[{
  RowBox[{"seq", "=", 
   RowBox[{"Flatten", "[", 
    RowBox[{"Insert", "[", 
     RowBox[{"segMinus", ",", "segPlus", ",", 
      RowBox[{"IntegerPart", "[", 
       RowBox[{
        RowBox[{"Length", "[", "segMinus", "]"}], "/", "2"}], "]"}]}], "]"}], 
    "]"}]}], ";"}]], "Input",
 FontColor->GrayLevel[0],
 Background->RGBColor[0.87, 0.94, 1]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"L", "=", 
  RowBox[{"Length", "[", "seq", "]"}]}]], "Input",
 FontColor->GrayLevel[0],
 Background->RGBColor[0.87, 0.94, 1]],

Cell[BoxData["12316"], "Output",
 CellChangeTimes->{3.6775715273420334`*^9}]
}, Open  ]],

Cell["\<\
Die Initialisierung und Rekursion erfolgen nun wie im Kasinobeispiel.\
\>", "Text",
 CellChangeTimes->{{3.6746310803384037`*^9, 3.6746311087984495`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"vit", "[", 
   RowBox[{"z1_", ",", "0", ",", "x_"}], "]"}], ":=", 
  RowBox[{"If", "[", 
   RowBox[{
    RowBox[{"z1", "==", "\"\<0\>\""}], ",", "1", ",", "0"}], "]"}]}]], "Input",
 FontColor->GrayLevel[0],
 Background->RGBColor[0.87, 0.94, 1]],

Cell[BoxData[
 RowBox[{"Do", "[", 
  RowBox[{
   RowBox[{"Do", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"tmpList", "=", 
          RowBox[{"Table", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"vit", "[", 
              RowBox[{
               RowBox[{"state", "[", 
                RowBox[{"[", "k", "]"}], "]"}], ",", 
               RowBox[{"i", "-", "1"}], ",", "seq"}], "]"}], "*", 
             RowBox[{"transition", "[", 
              RowBox[{
               RowBox[{"state", "[", 
                RowBox[{"[", "k", "]"}], "]"}], ",", 
               RowBox[{"state", "[", 
                RowBox[{"[", "j", "]"}], "]"}]}], "]"}]}], ",", 
            RowBox[{"{", 
             RowBox[{"k", ",", "1", ",", 
              RowBox[{"Length", "[", "state", "]"}]}], "}"}]}], "]"}]}], 
         ";"}], ",", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{
          RowBox[{"vit", "[", 
           RowBox[{
            RowBox[{"state", "[", 
             RowBox[{"[", "j", "]"}], "]"}], ",", "i", ",", "seq"}], "]"}], 
          "=", 
          RowBox[{
           RowBox[{"emission", "[", 
            RowBox[{
             RowBox[{"state", "[", 
              RowBox[{"[", "j", "]"}], "]"}], ",", 
             RowBox[{"seq", "[", 
              RowBox[{"[", "i", "]"}], "]"}]}], "]"}], "*", 
           RowBox[{"Max", "[", "tmpList", "]"}]}]}], ";"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"pointer", "[", 
          RowBox[{"j", ",", 
           RowBox[{"i", "-", "1"}]}], "]"}], "=", 
         RowBox[{
          RowBox[{"Flatten", "[", 
           RowBox[{"Position", "[", 
            RowBox[{"tmpList", ",", 
             RowBox[{"Max", "[", "tmpList", "]"}]}], "]"}], "]"}], "[", 
          RowBox[{"[", "1", "]"}], "]"}]}]}], "}"}], ";"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"j", ",", "1", ",", 
       RowBox[{"Length", "[", "state", "]"}]}], "}"}]}], "]"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{"i", ",", "1", ",", "L"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5741644041875*^9, 3.57416440471875*^9}},
 FontColor->GrayLevel[0],
 Background->RGBColor[0.87, 0.94, 1]],

Cell["\<\
Interessant ist nun wieder die Terminierung und die mit Traceback durchgef\
\[UDoubleDot]hrte Abfrage des wahrscheinlichsten Pfads:\
\>", "Text",
 CellChangeTimes->{{3.6746310581433706`*^9, 3.674631064012379*^9}, {
  3.6746311510125113`*^9, 3.6746311537745156`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"tmpList", "=", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"vit", "[", 
     RowBox[{
      RowBox[{"state", "[", 
       RowBox[{"[", "k", "]"}], "]"}], ",", "L", ",", "seq"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"k", ",", "1", ",", 
      RowBox[{"Length", "[", "state", "]"}]}], "}"}]}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0.`", ",", 
   "6.01600927617160967793556817497027797684`15.954589770191005*^-7379", ",", 
   "4.99562203636926737172513652198637860105461770449901122`15.\
954589770191005*^-7383"}], "}"}]], "Output",
 CellChangeTimes->{3.6775715430572615`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"pointerFinal", "=", 
  RowBox[{
   RowBox[{"Flatten", "[", 
    RowBox[{"Position", "[", 
     RowBox[{"tmpList", ",", 
      RowBox[{"Max", "[", "tmpList", "]"}]}], "]"}], "]"}], "[", 
   RowBox[{"[", "1", "]"}], "]"}]}]], "Input"],

Cell[BoxData["2"], "Output",
 CellChangeTimes->{3.677571543072861*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"pathX", "[", "L", "]"}], "=", "pointerFinal"}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{"Do", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"pathX", "[", 
     RowBox[{"i", "-", "1"}], "]"}], "=", 
    RowBox[{"pointer", "[", 
     RowBox[{
      RowBox[{"pathX", "[", "i", "]"}], ",", 
      RowBox[{"i", "-", "1"}]}], "]"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"i", ",", "L", ",", "1", ",", 
     RowBox[{"-", "1"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.57416442065625*^9, 3.5741644331875*^9}, 
   3.622884808432579*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"path", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"pathX", "[", "i", "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "1", ",", "L"}], "}"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.574164436375*^9, 3.574164440296875*^9}}],

Cell[TextData[{
 "\nMan erkennt, dass ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " selbst in dieser nicht-logarithmischen Variante des Viterbi-Algorithmus \
die (extrem kleinen) Zahlenwerte zu verwalten vermag. In den meisten anderen \
Programmierumgebungen ist allerdings die Verwendung der logarithmischen \
Variablen erforderlich. Die grafische Darstellung erfolgt nun, indem den \
einzelnen Nukleotiden verschiedene Graustufen zugewiesen werden. Die \
Nukleotide C und G sind dabei dunkel dargestellt, so dass sich eine \
Korrelation der CpG-Inseln mit dem CG-Gehalt optisch qualitativ \
\[UDoubleDot]berpr\[UDoubleDot]fen l\[ADoubleDot]sst. Wie schon zuvor werden \
neben der in Graustufen codierten Sequenz noch die tats\[ADoubleDot]chliche \
Annotation (CpG-Inseln als dunkelgraue Segmente) und die \
zugeh\[ODoubleDot]rige Viterbi-Decodierung abgebildet."
}], "Text",
 CellChangeTimes->{{3.674631248580656*^9, 3.674631260938675*^9}, 
   3.6774937884730215`*^9}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"seq2", " ", "=", " ", 
   RowBox[{"seq", "/.", " ", 
    RowBox[{
     RowBox[{"nn1_", " ", "/;", " ", 
      RowBox[{"nn1", " ", "=!=", "List"}]}], "\[Rule]", " ", 
     RowBox[{"{", 
      RowBox[{"nn1", ",", "nn1"}], "}"}]}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Dimensions", "[", "seq2", "]"}]}], "Input",
 FontColor->GrayLevel[0],
 Background->RGBColor[0.87, 0.94, 1]],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"2", ",", "12316"}], "}"}]], "Output",
 CellChangeTimes->{3.6775715431508617`*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"makeGCplot", "[", 
   RowBox[{"sss_", ",", "www_"}], "]"}], ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", "tx1", "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"tx1", " ", "=", " ", 
      RowBox[{"Map", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"1", "-", 
          RowBox[{"N", "[", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"Count", "[", 
               RowBox[{"#", ",", "\"\<C\>\""}], "]"}], "+", 
              RowBox[{"Count", "[", 
               RowBox[{"#", ",", "\"\<G\>\""}], "]"}]}], ")"}], "/", "www"}], 
           "]"}]}], "&"}], ",", 
        RowBox[{"Partition", "[", 
         RowBox[{"sss", ",", "www", ",", "1"}], "]"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"Graphics", "[", 
      RowBox[{
       RowBox[{"Raster", "[", 
        RowBox[{"{", 
         RowBox[{"tx1", ",", "tx1"}], "}"}], "]"}], ",", 
       RowBox[{"AspectRatio", "\[Rule]", "0.1"}]}], "]"}]}]}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.6239033889690647`*^9, 3.6239034948398247`*^9}, {
  3.623903872357695*^9, 3.623903872452519*^9}},
 FontColor->GrayLevel[0],
 Background->RGBColor[0.87, 0.94, 1]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"pl1", " ", "=", " ", 
   RowBox[{"makeGCplot", "[", 
    RowBox[{
     RowBox[{"seq2", "[", 
      RowBox[{"[", "2", "]"}], "]"}], ",", "100"}], "]"}]}], 
  "\[IndentingNewLine]"}]], "Input",
 CellChangeTimes->{{3.570522325223872*^9, 3.570522378973339*^9}, {
  3.5705224394881897`*^9, 3.5705225069713874`*^9}, {3.5705225805793495`*^9, 
  3.5705225923134985`*^9}, {3.570522682733638*^9, 3.5705226987958293`*^9}, {
  3.5705227884659824`*^9, 3.5705228233559375`*^9}, {3.5705228723862467`*^9, 
  3.570522873573724*^9}, {3.5705230711950135`*^9, 3.570523168131273*^9}, {
  3.6746466950970564`*^9, 3.67464671097008*^9}, {3.674647845109776*^9, 
  3.674647884826835*^9}},
 FontColor->GrayLevel[0],
 Background->RGBColor[0.87, 0.94, 1]],

Cell[BoxData[
 GraphicsBox[RasterBox[CompressedData["
1:eJy1nTvML9111i1KK2VqS3R2RUHacEook9SukKDFtV2b1pSBFmrXpv2UKBfZ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   "]],
  AspectRatio->0.1]], "Output",
 CellChangeTimes->{3.677571543447262*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"label1", " ", "=", " ", 
   RowBox[{
    RowBox[{"Flatten", "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Table", "[", 
        RowBox[{"0", ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Length", "[", "segMinus", "]"}], "/", "2"}], "}"}]}], 
        "]"}], ",", " ", 
       RowBox[{"Table", "[", 
        RowBox[{"1", ",", 
         RowBox[{"{", 
          RowBox[{"Length", "[", "segPlus", "]"}], "}"}]}], "]"}], ",", 
       RowBox[{"Table", "[", 
        RowBox[{"0", ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Length", "[", "segMinus", "]"}], "/", "2"}], "}"}]}], 
        "]"}]}], "}"}], "]"}], " ", "/.", " ", 
    RowBox[{
     RowBox[{"nn1_", " ", "/;", " ", 
      RowBox[{"nn1", " ", "=!=", "List"}]}], "\[Rule]", " ", 
     RowBox[{"{", 
      RowBox[{"nn1", ",", "nn1"}], "}"}]}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.570523334691641*^9, 3.570523338113472*^9}},
 FontColor->GrayLevel[0],
 Background->RGBColor[0.87, 0.94, 1]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"pl2", " ", "=", " ", 
  RowBox[{"Graphics", "[", 
   RowBox[{
    RowBox[{"Raster", "[", 
     RowBox[{"label1", " ", "/.", " ", 
      RowBox[{"Thread", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", "1"}], "}"}], "->", 
        RowBox[{"{", 
         RowBox[{"0.9", ",", "0.3"}], "}"}]}], "]"}]}], "]"}], ",", 
    RowBox[{"AspectRatio", "->", " ", "0.1"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.570523345082133*^9, 3.5705233799566865`*^9}},
 FontColor->GrayLevel[0],
 Background->RGBColor[0.87, 0.94, 1]],

Cell[BoxData[
 GraphicsBox[RasterBox[CompressedData["
1:eJzt3FEJgDAYhdEfc/hiA2EB7GAEwWeL6tNqLIRsJTbG+eByWtztes57iYi6
dY/43lo5SJIkSZIkSZIkSZIkSZIkSZIkSZIkSZIkSZIkSZIkSZIkSZIkSZIk
SZIkSZIkSZIkSZIkSZIkSZIkSZYjtTJJkiRJkiRJkiRJkiRJkiRJkiRJkiRJ
kiRJkpzI3v9GJEmSJEmSJEmSJEmSJEmSJEmSJEmSJEmSJEmSJEmSJEmSJEmS
JEmSJEmSJEmSJEmSJEmSJEmSJEmSJEmSJEmSJEmSJEmSJEmSJEmSJEmSJEmS
JEmSJEmSJEmSJEmSJEmSJEmSJEmSJEmSJEmSJEmSJEmSJMkxTa1MkiRJkiRJ
kiRJkiRJkiRJkiRJkiRJkiRJkiQnsve/EUmSJEmSJEmSJEmSJEmSJEmSJEmS
JEmSJEmSJEmSJEmSJEmSJEmSJEmSJEmSJEmSJEmSJEmSJEmSJDmSP7TANIA=

   "]],
  AspectRatio->0.1]], "Output",
 CellChangeTimes->{3.677571543587662*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"label2", " ", "=", " ", 
   RowBox[{"path", "/.", " ", 
    RowBox[{
     RowBox[{"nn1_", " ", "/;", " ", 
      RowBox[{"nn1", " ", "=!=", "List"}]}], "\[Rule]", " ", 
     RowBox[{"{", 
      RowBox[{"nn1", ",", "nn1"}], "}"}]}]}]}], ";"}]], "Input",
 FontColor->GrayLevel[0],
 Background->RGBColor[0.87, 0.94, 1]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Dimensions", "[", "label2", "]"}]], "Input",
 FontColor->GrayLevel[0],
 Background->RGBColor[0.87, 0.94, 1]],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"2", ",", "12316"}], "}"}]], "Output",
 CellChangeTimes->{3.677571543603262*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"pl3", "=", 
  RowBox[{"Graphics", "[", 
   RowBox[{
    RowBox[{"Raster", "[", 
     RowBox[{"label2", " ", "/.", 
      RowBox[{"Thread", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"1", ",", "2", ",", "3"}], "}"}], "->", 
        RowBox[{"{", 
         RowBox[{"1.0", ",", "0.9", ",", "0.3"}], "}"}]}], "]"}]}], "]"}], 
    ",", 
    RowBox[{"AspectRatio", "->", " ", "0.1"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.5705234447058573`*^9, 3.5705234757367105`*^9}},
 FontColor->GrayLevel[0],
 Background->RGBColor[0.87, 0.94, 1]],

Cell[BoxData[
 GraphicsBox[RasterBox[CompressedData["
1:eJzt3FEJgDAYhdEfc/hiA2EB7GAEwWeL6tNqGEK2ENuQ88HltLjLce3nFBFl
8xrx3KV3I0mSJEmSJEmSJEmSJEmSJEmSJEmSJEmSJEmSJEmSJEmSJEmSJEmS
JEmSJEmSJEmSJEmSJEmSbGWqZZIkSZIkSZIkSZIkSZIkSZIkSZIkSZIkSZIk
SZIkSZIcxt6/rSRJkiRJkiRJkiRJkiRJkiRJkiRJkiRJkiRJkiRJkiRJkiRJ
kiRJkiRJkiRJkiRJkiRJkiRJkiRJkiRJkiRJkiRJkiRJkiRJkiRJkiRJkiRJ
kiRJkiRJkiRJkiRJkiRJkiRJkiRJkiRJkiRJkiRJkn811TJJkiRJkiRJkiRJ
kiRJkiRJkiRJkiRJkiRJkiRJkiRJDmPv31aSJEmSJEmSJEmSJEmSJEmSJEmS
JEmSJEmSJEmSJEmSJEmSJEmSJEmSJEmSJEmSJEmSJEmSJEmSJMlWfmhWXKw=

   "]],
  AspectRatio->0.1]], "Output",
 CellChangeTimes->{3.6775715437436624`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{"GraphicsGrid", "[", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", "pl1", "}"}], ",", 
     RowBox[{"{", "pl2", "}"}], ",", 
     RowBox[{"{", "pl3", "}"}]}], "}"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.570523497048938*^9, 3.570523506752237*^9}},
 FontColor->GrayLevel[0],
 Background->RGBColor[0.87, 0.94, 1]],

Cell[BoxData[
 GraphicsBox[{{}, {InsetBox[
     GraphicsBox[RasterBox[CompressedData["
1:eJy1nTvML9111i1KK2VqS3R2RUHacEook9SukKDFtV2b1pSBFmrXpv2UKBfZ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       "]],
      AspectRatio->0.1], {189., -19.350000000000005`}, 
     ImageScaled[{0.5, 0.5}], {360., 36.00000000000001}], InsetBox[
     GraphicsBox[RasterBox[CompressedData["
1:eJzt3FEJgDAYhdEfc/hiA2EB7GAEwWeL6tNqLIRsJTbG+eByWtztes57iYi6
dY/43lo5SJIkSZIkSZIkSZIkSZIkSZIkSZIkSZIkSZIkSZIkSZIkSZIkSZIk
SZIkSZIkSZIkSZIkSZIkSZIkSZYjtTJJkiRJkiRJkiRJkiRJkiRJkiRJkiRJ
kiRJkpzI3v9GJEmSJEmSJEmSJEmSJEmSJEmSJEmSJEmSJEmSJEmSJEmSJEmS
JEmSJEmSJEmSJEmSJEmSJEmSJEmSJEmSJEmSJEmSJEmSJEmSJEmSJEmSJEmS
JEmSJEmSJEmSJEmSJEmSJEmSJEmSJEmSJEmSJEmSJEmSJMkxTa1MkiRJkiRJ
kiRJkiRJkiRJkiRJkiRJkiRJkiQnsve/EUmSJEmSJEmSJEmSJEmSJEmSJEmS
JEmSJEmSJEmSJEmSJEmSJEmSJEmSJEmSJEmSJEmSJEmSJEmSJDmSP7TANIA=

       "]],
      AspectRatio->0.1], {189., -58.05000000000002}, 
     ImageScaled[{0.5, 0.5}], {360., 36.000000000000014`}], InsetBox[
     GraphicsBox[RasterBox[CompressedData["
1:eJzt3FEJgDAYhdEfc/hiA2EB7GAEwWeL6tNqGEK2ENuQ88HltLjLce3nFBFl
8xrx3KV3I0mSJEmSJEmSJEmSJEmSJEmSJEmSJEmSJEmSJEmSJEmSJEmSJEmS
JEmSJEmSJEmSJEmSJEmSbGWqZZIkSZIkSZIkSZIkSZIkSZIkSZIkSZIkSZIk
SZIkSZIcxt6/rSRJkiRJkiRJkiRJkiRJkiRJkiRJkiRJkiRJkiRJkiRJkiRJ
kiRJkiRJkiRJkiRJkiRJkiRJkiRJkiRJkiRJkiRJkiRJkiRJkiRJkiRJkiRJ
kiRJkiRJkiRJkiRJkiRJkiRJkiRJkiRJkiRJkiRJkn811TJJkiRJkiRJkiRJ
kiRJkiRJkiRJkiRJkiRJkiRJkiRJDmPv31aSJEmSJEmSJEmSJEmSJEmSJEmS
JEmSJEmSJEmSJEmSJEmSJEmSJEmSJEmSJEmSJEmSJEmSJEmSJMlWfmhWXKw=

       "]],
      AspectRatio->0.1], {189., -96.75000000000003}, 
     ImageScaled[{0.5, 0.5}], {360., 36.000000000000014`}]}, {}},
  ContentSelectable->True,
  PlotRangePadding->{6, 5}]], "Output",
 CellChangeTimes->{
  3.6775715441024632`*^9},ImageCache->GraphicsData["CompressedBitmap", "\<\
eJztnF9H5GEUx59+rd2rbZO9WF3N3b6AblaXe7FDWolIGjFGmWTb0ZSdjUQk
EolIJBKJSCQS6bJ30ts4ez5neobdy9WutX3pN8+fc57z7znP57LP1cX69Jfq
4mytWiovVBv12Vqz9Onrgm91d6XUNZlSmi4l5ubTxx/zP6vww87TzN8xNOzh
4eGjDQ8Pf2PWL9HzEf2Jpvqb80itRUIfSO37r1lL9J+L/oUm/K2mTS9se3vb
lpaWrFqtWqPRKGx1dTW9jeXc3Jytr6/bxcWF3d3d2enpaai7mrVaLTRtc3Mz
dHZ2dmxrayv2mB8cHNja2lrsubxAMZXs7OzMLi8vw9Te3l6oz8/PW7PZjBGz
y8vLtrKyEscxv7u7G2aQ1et1q9VqNjU1FSPy/f39cIceZ9GpVCqd8HMYx8fH
Bc7Te6Z2cnJi5+fnEdLR0VHsMWf/8PAwzGGaNeEyIr+6uooR14RJ8XCVq0KF
cEdIuM8hMUfGyJp0OcN5Qny0lQo0UnfYp5L+pfat9IYOPjhDybAzMzPTmZP2
+Ph4lIaYKNPo6KhNTEygV3Ct6XVsZ1VEqIyNjcVevnhCwyRzThVIU0+cQZcR
O3nk7NDQkI2MjFi5XLbBwUEbGBiIucvbx7sjWly6mpt0x+lVmMNtDok1Ov7K
XMdXqa+TEeezLntUkepRVaqTK0FIrGkwKsa+32hB13kYXC6Xf3197S5CQIP2
RcXpBm5vY2MjbGAbO3nNjebbRM+NRDMTBzG6r/aF9XSagZELzY2R30F+WjQV
a/Y9rsLu7+/9OGIsM9KTZJHbOXsjKnr39vY2dDyDyCi9jKApBB9FoW08gYKq
pTeRByq5dljM7zfnR9B4yDp49Hp60TwGx0d+90Tmd9LusN6fmpsvm8nlpP7k
e3Nzk+8hakCi/uj6xSgxSowSo8QoMUqMEqPEKDFKjBKjxCgxSowSo8QoMUqM
EqPEKDFKjBKjxCgxSowSo8QoMUqMEqPEKDFKjBKjxCgxSowSo8QoMUqMEqPE
KDFKjBKjxCgxSowSo8QoMUqMEqPEKDFKjBKjxCgxSowSo8QoMUqMEqPEKDFK
jBKjxCgxSowSo8QoMUqMEqPEKDHq+TDqqf7ncOr6AcjlygY=\
\>"]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"seq2", " ", "=", " ", 
   RowBox[{"seq", "/.", " ", 
    RowBox[{
     RowBox[{"nn1_", " ", "/;", " ", 
      RowBox[{"nn1", " ", "=!=", "List"}]}], "\[Rule]", " ", 
     RowBox[{"{", 
      RowBox[{"nn1", ",", "nn1"}], "}"}]}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Dimensions", "[", "seq2", "]"}]}], "Input",
 FontColor->GrayLevel[0],
 Background->RGBColor[0.87, 0.94, 1]],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"2", ",", "12316"}], "}"}]], "Output",
 CellChangeTimes->{3.6775715442116632`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"makeGCplot", "[", 
  RowBox[{
   RowBox[{"seq2", "[", 
    RowBox[{"[", "2", "]"}], "]"}], ",", "100"}], "]"}]], "Input",
 CellChangeTimes->{{3.623903891762581*^9, 3.623903898203142*^9}},
 FontColor->GrayLevel[0],
 Background->RGBColor[0.87, 0.94, 1]],

Cell[BoxData[
 GraphicsBox[RasterBox[CompressedData["
1:eJy1nTvML9111i1KK2VqS3R2RUHacEook9SukKDFtV2b1pSBFmrXpv2UKBfZ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   "]],
  AspectRatio->0.1]], "Output",
 CellChangeTimes->{3.677571544476864*^9}]
}, Open  ]],

Cell[TextData[{
 "Abbildung 2.62 a stellt das Resultat der Grafikausgabe zusammen. Zwar wird \
das eingeschobene Segment in seiner Ausdehnung etwas \[UDoubleDot]bersch\
\[ADoubleDot]tzt, aber dennoch ist das Viterbi-Resultat in guter qualitativer \
\[CapitalUDoubleDot]bereinstimmung mit der tats\[ADoubleDot]chlichen \
Annotation. Wenden wir nun dieses Hidden-Markov-Modell auf eine reale Sequenz \
an. Abbildung 2.62b zeigt das Resultat des Viterbi-Algorithmus \
f\[UDoubleDot]r ein 100 000 bp langes Sequenzsegment aus Chromosom 19, \
zusammen mit den tats\[ADoubleDot]chlich durch die Software von Takai und \
Jones identifizierten CpG-Inseln in diesem Segment. Wie zu erwarten (aufgrund \
der sehr einfachen Modellstruktur) weist das Viterbi-Resultat eine gro\[SZ]e \
Zahl von ",
 StyleBox["false positives",
  FontSlant->"Italic"],
 " auf. Die in diesem Segment tats\[ADoubleDot]chlich vorhandenen CpG-Inseln \
werden jedoch gefunden."
}], "Text",
 CellChangeTimes->{{3.6746312881727147`*^9, 3.6746312996767316`*^9}, {
  3.674631371041839*^9, 3.6746313769978476`*^9}}]
}, Open  ]]
},
WindowSize->{507, 900},
WindowMargins->{{578, Automatic}, {Automatic, 117}},
PrivateNotebookOptions->{"VersionedStylesheet"->{"Default.nb"[8.] -> False}},
FrontEndVersion->"10.4 for Microsoft Windows (64-bit) (April 11, 2016)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[558, 20, 870, 36, 182, "Subsubtitle"],
Cell[CellGroupData[{
Cell[1453, 60, 232, 7, 66, "Subtitle"],
Cell[1688, 69, 1978, 35, 543, "Text"],
Cell[3669, 106, 187, 5, 47, "Input"],
Cell[3859, 113, 567, 13, 92, "Input"],
Cell[4429, 128, 375, 6, 87, "Text"],
Cell[4807, 136, 230, 7, 31, "Input"],
Cell[CellGroupData[{
Cell[5062, 147, 270, 7, 31, "Input"],
Cell[5335, 156, 1295, 35, 72, "Output"]
}, Open  ]],
Cell[6645, 194, 759, 21, 92, "Input"],
Cell[CellGroupData[{
Cell[7429, 219, 109, 2, 31, "Input"],
Cell[7541, 223, 592, 11, 92, "Output"]
}, Open  ]],
Cell[8148, 237, 174, 4, 49, "Text"],
Cell[8325, 243, 182, 5, 31, "Input"],
Cell[CellGroupData[{
Cell[8532, 252, 239, 6, 72, "Input"],
Cell[8774, 260, 578, 11, 92, "Output"]
}, Open  ]],
Cell[9367, 274, 543, 16, 112, "Input"],
Cell[CellGroupData[{
Cell[9935, 294, 69, 1, 31, "Input"],
Cell[10007, 297, 1085, 24, 101, "Output"]
}, Open  ]],
Cell[11107, 324, 575, 9, 125, "Text"],
Cell[11685, 335, 452, 11, 112, "Input"],
Cell[12140, 348, 320, 6, 68, "Text"],
Cell[CellGroupData[{
Cell[12485, 358, 103, 2, 31, "Input"],
Cell[12591, 362, 590, 11, 92, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[13218, 378, 238, 6, 72, "Input"],
Cell[13459, 386, 583, 11, 92, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[14079, 402, 111, 3, 31, "Input"],
Cell[14193, 407, 1092, 24, 101, "Output"]
}, Open  ]],
Cell[15300, 434, 391, 7, 87, "Text"],
Cell[15694, 443, 176, 5, 31, "Input"],
Cell[CellGroupData[{
Cell[15895, 452, 70, 1, 31, "Input"],
Cell[15968, 455, 1255, 32, 101, "Output"]
}, Open  ]],
Cell[17238, 490, 1444, 24, 391, "Text"],
Cell[18685, 516, 1038, 30, 132, "Input"],
Cell[19726, 548, 319, 7, 68, "Text"],
Cell[20048, 557, 415, 10, 72, "Input"],
Cell[20466, 569, 202, 7, 31, "Input"],
Cell[20671, 578, 374, 6, 68, "Text"],
Cell[21048, 586, 729, 15, 92, "Input"],
Cell[21780, 603, 779, 15, 182, "Text"],
Cell[22562, 620, 189, 7, 31, "Input"],
Cell[22754, 629, 428, 14, 52, "Input"],
Cell[23185, 645, 453, 11, 112, "Input"],
Cell[23641, 658, 274, 9, 52, "Input"],
Cell[23918, 669, 544, 12, 72, "Input"],
Cell[CellGroupData[{
Cell[24487, 685, 462, 13, 52, "Input"],
Cell[24952, 700, 10874, 316, 232, "Output"]
}, Open  ]],
Cell[35841, 1019, 1379, 26, 372, "Text"],
Cell[37223, 1047, 391, 9, 72, "Input"],
Cell[CellGroupData[{
Cell[37639, 1060, 391, 12, 72, "Input"],
Cell[38033, 1074, 76, 1, 31, "Output"]
}, Open  ]],
Cell[38124, 1078, 366, 7, 87, "Text"],
Cell[38493, 1087, 169, 5, 52, "Input"],
Cell[CellGroupData[{
Cell[38687, 1096, 88, 2, 31, "Input"],
Cell[38778, 1100, 1408, 22, 232, "Output"]
}, Open  ]],
Cell[40201, 1125, 443, 8, 106, "Text"],
Cell[40647, 1135, 307, 9, 72, "Input"],
Cell[CellGroupData[{
Cell[40979, 1148, 95, 2, 31, "Input"],
Cell[41077, 1152, 75, 1, 31, "Output"]
}, Open  ]],
Cell[41167, 1156, 142, 1, 30, "Text"],
Cell[CellGroupData[{
Cell[41334, 1161, 67, 1, 31, "Input"],
Cell[41404, 1164, 95, 2, 31, "Output"]
}, Open  ]],
Cell[41514, 1169, 1476, 56, 198, "Text"],
Cell[CellGroupData[{
Cell[43015, 1229, 181, 6, 31, "Input"],
Cell[43199, 1237, 88, 1, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[43324, 1243, 121, 3, 31, "Input"],
Cell[43448, 1248, 90, 1, 31, "Output"]
}, Open  ]],
Cell[43553, 1252, 312, 5, 68, "Text"],
Cell[CellGroupData[{
Cell[43890, 1261, 451, 14, 72, "Input"],
Cell[44344, 1277, 218, 5, 31, "Output"]
}, Open  ]],
Cell[44577, 1285, 664, 19, 125, "Text"],
Cell[45244, 1306, 719, 16, 88, "Input"],
Cell[CellGroupData[{
Cell[45988, 1326, 256, 6, 47, "Input"],
Cell[46247, 1334, 99, 2, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[46383, 1341, 521, 16, 88, "Input"],
Cell[46907, 1359, 79, 1, 31, "Output"]
}, Open  ]],
Cell[47001, 1363, 292, 7, 47, "Input"],
Cell[CellGroupData[{
Cell[47318, 1374, 266, 8, 68, "Input"],
Cell[47587, 1384, 88, 1, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[47712, 1390, 197, 5, 47, "Input"],
Cell[47912, 1397, 92, 1, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[48041, 1403, 595, 19, 88, "Input"],
Cell[48639, 1424, 198, 5, 31, "Output"]
}, Open  ]],
Cell[48852, 1432, 289, 6, 65, "Text"],
Cell[49144, 1440, 236, 7, 47, "Input"],
Cell[49383, 1449, 301, 9, 47, "Input"],
Cell[CellGroupData[{
Cell[49709, 1462, 279, 8, 47, "Input"],
Cell[49991, 1472, 485, 14, 72, "Output"]
}, Open  ]],
Cell[50491, 1489, 609, 18, 88, "Input"],
Cell[CellGroupData[{
Cell[51125, 1511, 164, 4, 47, "Input"],
Cell[51292, 1517, 89, 1, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[51418, 1523, 251, 7, 47, "Input"],
Cell[51672, 1532, 90, 1, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[51799, 1538, 247, 7, 47, "Input"],
Cell[52049, 1547, 91, 1, 31, "Output"]
}, Open  ]],
Cell[52155, 1551, 1449, 36, 228, "Input"],
Cell[53607, 1589, 483, 8, 122, "Text"],
Cell[54093, 1599, 453, 7, 87, "Text"],
Cell[54549, 1608, 391, 9, 72, "Input"],
Cell[54943, 1619, 133, 4, 31, "Input"],
Cell[CellGroupData[{
Cell[55101, 1627, 65, 1, 31, "Input"],
Cell[55169, 1630, 75, 1, 31, "Output"]
}, Open  ]],
Cell[55259, 1634, 518, 13, 128, "Input"],
Cell[55780, 1649, 262, 8, 47, "Input"],
Cell[56045, 1659, 373, 11, 68, "Input"],
Cell[CellGroupData[{
Cell[56443, 1674, 148, 4, 47, "Input"],
Cell[56594, 1680, 76, 1, 31, "Output"]
}, Open  ]],
Cell[56685, 1684, 163, 3, 49, "Text"],
Cell[56851, 1689, 279, 8, 47, "Input"],
Cell[57133, 1699, 2276, 63, 308, "Input"],
Cell[59412, 1764, 276, 5, 68, "Text"],
Cell[CellGroupData[{
Cell[59713, 1773, 347, 10, 52, "Input"],
Cell[60063, 1785, 287, 7, 55, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[60387, 1797, 256, 7, 52, "Input"],
Cell[60646, 1806, 70, 1, 31, "Output"]
}, Open  ]],
Cell[60731, 1810, 111, 3, 31, "Input"],
Cell[60845, 1815, 466, 14, 52, "Input"],
Cell[61314, 1831, 289, 8, 31, "Input"],
Cell[61606, 1841, 979, 17, 296, "Text"],
Cell[CellGroupData[{
Cell[62610, 1862, 417, 11, 88, "Input"],
Cell[63030, 1875, 121, 3, 31, "Output"]
}, Open  ]],
Cell[63166, 1881, 1247, 35, 168, "Input"],
Cell[CellGroupData[{
Cell[64438, 1920, 761, 16, 68, "Input"],
Cell[65202, 1938, 17734, 293, 51, "Output"]
}, Open  ]],
Cell[82951, 2234, 1036, 30, 128, "Input"],
Cell[CellGroupData[{
Cell[84012, 2268, 560, 15, 128, "Input"],
Cell[84575, 2285, 626, 13, 51, "Output"]
}, Open  ]],
Cell[85216, 2301, 351, 10, 68, "Input"],
Cell[CellGroupData[{
Cell[85592, 2315, 132, 3, 47, "Input"],
Cell[85727, 2320, 119, 3, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[85883, 2328, 574, 16, 148, "Input"],
Cell[86460, 2346, 628, 13, 51, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[87125, 2364, 369, 10, 47, "Input"],
Cell[87497, 2376, 20476, 344, 116, 19226, 322, "CachedBoxData", "BoxData", \
"Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[108010, 2725, 417, 11, 88, "Input"],
Cell[108430, 2738, 121, 3, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[108588, 2746, 275, 7, 47, "Input"],
Cell[108866, 2755, 17734, 293, 51, "Output"]
}, Open  ]],
Cell[126615, 3051, 1074, 18, 277, "Text"]
}, Open  ]]
}
]
*)

